==> datana_1.1.2.tar.gz: datana/R/tabtexdescstat.r <==
#' Function to create a LaTeX file for a table of
#'  descriptive statistics of continuous variables from a dataframe.
#' 
#' @details The resulting file is a LaTeX table, that can be
#' added to your main LaTeX document by using `\input{filename}`.
#' 
#' @title Creates a LaTeX file having a descriptive statistics table
#' for continuous variables
#' @param data a dataframe containing numeric variables as columns.
#' @param colnames a string having the column names of the dataframe
#' to which the descriptive statistics will be computed.
#' @param varnames a string having the name of each of the variables
#' to be used in the LaTeX table.
#' @param cap a string having the caption of the LaTeX table.
#' @param variable.row A logical option specifying whether the
#' variables are used in the rows of the output. The default is
#' to FALSE, thus, the variables are used as the main colum of the
#' table. 
#' @param nametab a string having a brief name to be used in
#' both the label of the table and the file name. For instance,
#' if "=descdata", the table can be refered in your LaTeX
#' document by using `\ref{tab:descdata}`
#' @param save.file The defauls is set to ``FALSE'', if is set to
#' TRUE, then the option `filename` must be provided.
#' @param filename A string having the name of the resulting LaTeX
#' file having the table. The default is set to "tabdescdata.tex".
#' @param eng The language to be used in the output. English
#'  is the default, meanwhile if `eng`=FALSE, Spanish is used.
#' @param rowlab a character with the name to be used as label for
#' the column where the variables will be printed. The default is
#' set to "Variables".
#' @param decnum the number of decimals to be used in the output. The
#' default is set to 3.
#' @param font.size.tab The defauls is set to "normalsize". You could
#'  also try with "footnotesize". 
#' @param font.type.tab The defauls is set to "normalfont".
#' @importFrom utils head
#'
#' @return This function creates a LaTeX file having 
#' the following descriptive statistics: sample size, minimum,
#' maximum, mean, median, SD, and coefficient of variation. 
#'   If the full option is set to TRUE, the following statistics
#' are added to the table: 25th and 75th percentiles, the
#' interquartile range, skewness, and kurtosis.
#' @author Christian Salas-Eljatib.
#' @references
#' Salas-Eljatib, C. 2021. Análisis de datos con el programa
#' estadístico R: una introducción aplicada. Ediciones Universidad
#' Mayor, Santiago, Chile. 170 p. \url{https://eljatib.com/rlibro}
#' @examples
#'
#' df <- datana::idahohd
#' head(df)
#' ##example 1
#' tabtexdescstat(data=df,nametab="idaho",
#'  cap="Descriptive statistics table",
#' colnames=c("dbh","toth"),varnames = c("Diameter","Height"))
#' ##example 2
#' tabtexdescstat(data=df,nametab="idaho",
#' cap="Cuadro con estadistica descriptiva",
#'  colnames=c("dbh","toth"),varnames = c("Diametro","Altura"),
#'  eng=FALSE)
#' ##! Example 3: variables as columns
#' tabtexdescstat(data=df,nametab="idaho",
#'  cap="Descriptive statistics table",colnames=c("dbh","toth"),
#' varnames = c("Diameter","Height"),variable.row=FALSE)
#' @rdname tabtexdescstat
#' @export
#' 
##@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@
tabtexdescstat<-function(data=data,colnames=colnames,
                         varnames=varnames,cap=cap,nametab=nametab,
                         save.file=FALSE,filename="tabdescdata.tex",
   eng=TRUE,rowlab="Variable",decnum=3,font.size.tab="normalsize",
   font.type.tab="normalfont",variable.row=FALSE){

df.h<-data[,colnames]

all.out<-datana::descstat(df.h,decnum = decnum,all.outputs = TRUE,eng=TRUE)

stat.names<-all.out$stat.names
    
if(variable.row==TRUE){tab.h <- t(all.out$output)}
if(variable.row==FALSE){tab.h <- all.out$output}   
tab.h
if(variable.row==TRUE){row.names(tab.h)<-varnames}    
if(variable.row==TRUE){colnames(tab.h)<-stat.names}
    
if(variable.row==FALSE){rowlab<-"Statistics"}    
if(variable.row==FALSE & eng==FALSE){rowlab<-"Estadistico"}
    
tab.h

if(save.file==TRUE){    
fileNametex<-filename
}

rowlabel.h <-rowlab
labtab.h <- paste("tab:",nametab,sep = "")

if(save.file==TRUE){
l <-Hmisc::latex(tab.h,
 size=font.size.tab, cgroupTexCmd=font.type.tab,rowlabel=rowlabel.h, 
 file=fileNametex, col.just=rep("c",ncol(tab.h)),
 first.hline.double=FALSE,double.slash=FALSE,caption=cap,
 caption.loc="top",label=labtab.h,where="!h")}
    
    if(save.file==FALSE){
message("=======Start of the output=======")                
message("The following is the LaTeX output table","\n")        
Hmisc::latex(tab.h,file="",
 size=font.size.tab, cgroupTexCmd=font.type.tab,rowlabel=rowlabel.h, 
  col.just=rep("c",ncol(tab.h)),
 first.hline.double=FALSE,double.slash=FALSE,caption=cap,
 caption.loc="top",label=labtab.h,where="!h")        
message("=======End of the output=======","\n")                  
    }
}

==> datana_1.1.3.tar.gz: datana/R/tabtexdescstat.r <==
#' Function to create a LaTeX file for a table of
#'  descriptive statistics of continuous variables from a dataframe.
#' 
#' @details The resulting file is a LaTeX table, that can be
#' added to your main LaTeX document by using `\input{filename}`.
#' 
#' @title Creates a LaTeX file having a descriptive statistics table
#' for continuous variables
#' @param data a dataframe containing numeric variables as columns.
#' @param colnames a string having the column names of the dataframe
#' to which the descriptive statistics will be computed.
#' @param varnames a string having the name of each of the variables
#' to be used in the LaTeX table.
#' @param cap a string having the caption of the LaTeX table.
#' @param landscape logical; this option is passed to the
#' function `descstat()` that is call from this current function. By
#' default is set to `FALSE`, thus the output table will have the
#' statistics as rows, and in each column the variables.
#' Otherwise, if `TRUE` the variables will be the rows, and each
#' statistics the columns. Therefore this last option is only
#' advisable when `full=FALSE`.
#' @param nametab a string having a brief name to be used in
#' both the label of the table and the file name. For instance,
#' if "=descdata", the table can be refered in your LaTeX
#' document by using `\ref{tab:descdata}`
#' @param save.file The defauls is set to ``FALSE'', if is set to
#' TRUE, then the option `filename` must be provided.
#' @param filename A string having the name of the resulting LaTeX
#' file having the table. The default is set to "tabdescdata.tex".
#' @param eng The language to be used in the output. English
#'  is the default, meanwhile if `eng`=FALSE, Spanish is used.
#' @param rowlab a character with the name to be used as label for
#' the column where the variables will be printed. The default is
#' set to "Variables".
#' @param decnum the number of decimals to be used in the output. The
#' default is set to 3.
#' @param font.size.tab The defauls is set to "normalsize". You could
#'  also try with "footnotesize". 
#' @param font.type.tab The defauls is set to "normalfont".
#' @importFrom utils head
#'
#' @return This function creates a LaTeX file having 
#' the following descriptive statistics: sample size, minimum,
#' maximum, mean, median, SD, and coefficient of variation. 
#'   If the full option is set to TRUE, the following statistics
#' are added to the table: 25th and 75th percentiles, the
#' interquartile range, skewness, and kurtosis.
#' @author Christian Salas-Eljatib.
#' @references
#' Salas-Eljatib, C. 2021. Análisis de datos con el programa
#' estadístico R: una introducción aplicada. Ediciones Universidad
#' Mayor, Santiago, Chile. 170 p. \url{https://eljatib.com/rlibro}
#' @examples
#'
#' df <- datana::idahohd
#' head(df)
#' ##example 1
#' tabtexdescstat(data=df,nametab="idaho",
#'  cap="Descriptive statistics table",
#' colnames=c("dbh","toth"),varnames = c("Diameter","Height"))
#' ##example 2
#' tabtexdescstat(data=df,nametab="idaho",
#' cap="Cuadro con estadistica descriptiva",
#'  colnames=c("dbh","toth"),varnames = c("Diametro","Altura"),
#'  eng=FALSE)
#' ##! Example 3: variables as columns
#' tabtexdescstat(data=df,nametab="idaho",
#'  cap="Descriptive statistics table",colnames=c("dbh","toth"),
#' varnames = c("Diameter","Height"),landscape=TRUE)
#' @rdname tabtexdescstat
#' @export
#' 
##@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@
tabtexdescstat<-function(data=data,colnames=colnames,
                         varnames=varnames,cap=cap,nametab=nametab,
                         save.file=FALSE,filename="tabdescdata.tex",
   eng=TRUE,rowlab="Variable",decnum=3,font.size.tab="normalsize",
   font.type.tab="normalfont",landscape=FALSE){

df.h<-data[,colnames]
all.out<-datana::descstat(df.h,decnum = decnum,all.outputs = TRUE,
      eng=eng,landscape=landscape)

stat.names<-all.out$stat.names;stat.names
    
#if(landscape==TRUE){tab.h <- t(all.out$table)}  ##$output
#if(landscape==FALSE){tab.h <- all.out$table}   
    tab.h <- all.out$table;tab.h
    varnames
if(landscape==TRUE){row.names(tab.h)<-varnames}    
if(landscape==TRUE){colnames(tab.h)<-stat.names}

if(eng==TRUE){statistics.name<-"Statistics"}
if(eng==FALSE){statistics.name<-"Estadistico"}
    
if(landscape==FALSE){rowlab<-statistics.name}
    
tab.h

if(save.file==TRUE){    
fileNametex<-filename
}

rowlabel.h <-rowlab
labtab.h <- paste("tab:",nametab,sep = "")

if(save.file==TRUE){
l <-Hmisc::latex(tab.h,
 size=font.size.tab, cgroupTexCmd=font.type.tab,rowlabel=rowlabel.h, 
 file=fileNametex, col.just=rep("c",ncol(tab.h)),
 first.hline.double=FALSE,double.slash=FALSE,caption=cap,
 caption.loc="top",label=labtab.h,where="!h")}
    
    if(save.file==FALSE){
message("=======Start of the output=======")                
message("The following is the LaTeX output table","\n")        
Hmisc::latex(tab.h,file="",
 size=font.size.tab, cgroupTexCmd=font.type.tab,rowlabel=rowlabel.h, 
  col.just=rep("c",ncol(tab.h)),
 first.hline.double=FALSE,double.slash=FALSE,caption=cap,
 caption.loc="top",label=labtab.h,where="!h")        
message("=======End of the output=======","\n")                  
    }
}
